@@ -29,15 +29,15 @@ class ScilabCompletionObject : public Cantor::CompletionObject
 {
     public:
         ScilabCompletionObject(const QString& cmd, int index, ScilabSession* session) ;
-        ~ScilabCompletionObject() override;
+        ~ScilabCompletionObject() override = default;
 
     protected:
-        bool mayIdentifierContain(QChar c) const Q_DECL_OVERRIDE;
-        bool mayIdentifierBeginWith(QChar c) const Q_DECL_OVERRIDE;
+        bool mayIdentifierContain(QChar c) const override;
+        bool mayIdentifierBeginWith(QChar c) const override;
 
     protected Q_SLOTS:
-        void fetchCompletions() Q_DECL_OVERRIDE;
-        void fetchIdentifierType() Q_DECL_OVERRIDE;
+        void fetchCompletions() override;
+        void fetchIdentifierType() override;
 };
 
 #endif /* _SCILABCOMPLETIONOBJECT_H */
